mysql.stmt.bind_in.Base_In_String

Package mysql :: Package stmt :: Module bind_in :: Class Base_In_String |
[hide private]
[frames] | no frames]

# Class Base_In_String

    object --+
             |
    Input_Bind --+
                 |
                Base_In_String

Known Subclasses:
  In_Char, In_Varchar

Base class input binding that is a character array from a string.

All input string types take a third argument which is the maximum size of the buffer.

If you attempt to give an input value that is larger than the specified maximum size, then the call to `execute` will raise `OverflowError`.

Instance Methods | [hide private]
`` | __init__(...) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
`` | __new__(T, S, ...) Returns a new object with type S, a subtype of T...
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
`` | __pyx_vtable__ = `<PyCObject object at 0x852e4e8>`

Instance Variables | [hide private]
`` | _value The `char *` character array, allocated in `__init__`.
Inherited from `Input_Bind` (private): `_buffer`, `_buffer_length`, `_buffer_type`, `_is_null`, `_is_unsigned`, `_length`, `_what`, `_who`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(...) (Constructor) |
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: Input_Bind.__init__

### __new__(T, S, ...) |
    Returns:
        a new object with type S, a subtype of T
Overrides: Input_Bind.__new__

Class Variable Details | [hide private]

    ### __pyx_vtable__ Value:
        <PyCObject object at 0x852e4e8>

Instance Variable Details | [hide private]

### _value The `char *` character array, allocated in `__init__`. (C only.)